YARP 2.3.3 (2010-12-17)                                                {#v2_3_3}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.2...v2.3.3`):

```
     9	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     8	Lorenzo Natale <lorenzo.natale@iit.it>
     5	Alessandro Scalzo <alessandro.scalzo@iit.it>
     4	Ugo Pattacini <ugo.pattacini@iit.it>
     3	Marco Randazzo <marco.randazzo@iit.it>
```
